==> haskell-deferred-folds-0.9.18.2-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deferred-folds
version:              0.9.18.2
visibility:           public
id:                   deferred-folds-0.9.18.2-qYxd64sckF4qZdWLKou0X
key:                  deferred-folds-0.9.18.2-qYxd64sckF4qZdWLKou0X
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
stability:            Experimental
homepage:             https://github.com/metrix-ai/deferred-folds
synopsis:             Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.

category:             Folding
abi:                  fc2fc1f506ad52e06ac137b20b8006f5
exposed:              True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr

hidden-modules:
    DeferredFolds.Types DeferredFolds.UnfoldrM
    DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
    DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
    DeferredFolds.Prelude DeferredFolds.Util.TextArray

import-dirs:          /usr/lib/ghc-9.0.2/site-local/deferred-folds-0.9.18.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/deferred-folds-0.9.18.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deferred-folds
hs-libraries:         HSdeferred-folds-0.9.18.2-qYxd64sckF4qZdWLKou0X
depends:
    base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    foldl-1.4.12-3CCgO75sGh4GI4BiONan6b
    hashable-1.4.1.0-LUNCtsUMK7L3ZB2KEKWF7F
    primitive-0.7.4.0-CfTIpXUHtu665Ilg6bT1BW text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-1t66PwyRMuzEgWVME6Xx4r
    vector-0.13.0.0-80dNWv5W93FGfZf7Ao5mAf

haddock-interfaces:
    /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock

haddock-html:         /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deferred-folds-0.9.18.3-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deferred-folds
version:              0.9.18.3
visibility:           public
id:                   deferred-folds-0.9.18.3-1t59xwRtFhg3IJqAGQdlIS
key:                  deferred-folds-0.9.18.3-1t59xwRtFhg3IJqAGQdlIS
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
stability:            Experimental
homepage:             https://github.com/metrix-ai/deferred-folds
synopsis:             Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.

category:             Folding
abi:                  7058be82df9c30081757b2d1f1ab26d8
exposed:              True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr

hidden-modules:
    DeferredFolds.Types DeferredFolds.UnfoldrM
    DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
    DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
    DeferredFolds.Prelude DeferredFolds.Util.TextArray

import-dirs:          /usr/lib/ghc-9.0.2/site-local/deferred-folds-0.9.18.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/deferred-folds-0.9.18.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deferred-folds
hs-libraries:         HSdeferred-folds-0.9.18.3-1t59xwRtFhg3IJqAGQdlIS
depends:
    base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    foldl-1.4.15-BO7SBgcDqvqCwQmVtptklZ
    hashable-1.4.2.0-8JSq7I7AhyyZ2Q90BxZWW
    primitive-0.7.4.0-8RUdbvjRYjOFHQ1vgzaS7Q text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-Km0aDxhChoIJJSbiufyazz
    vector-0.13.0.0-9fyHsAonVFcGYv9jtLmfSh

haddock-interfaces:
    /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock

haddock-html:         /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
